
#if defined(ESP32)
#include <WiFi.h>
#elif defined(ESP8266)
#include <ESP8266WiFi.h>
#endif
#include <ESP_Mail_Client.h>

#define WIFI_SSID "XXXXX"                             // Название WIFI сети
#define WIFI_PASSWORD "XXXXXXXX"                      // Пароль WIFI сети

#define SMTP_HOST "smtp.gmail.com"                    // SMTP сервер smtp.gmail.com   smtp.yandex.ru    smtp.mail.ru

// SMTP порт
/** 
 * 25  or esp_mail_smtp_port_25
 * 465 or esp_mail_smtp_port_465
 * 587 or esp_mail_smtp_port_587
*/
#define SMTP_PORT 465

// Учетные данные для входа (адрес электронной почты и пароль, используемые для отправки сообщений)
#define AUTHOR_EMAIL "XXXXXXXXXX@gmail.com"  
#define AUTHOR_PASSWORD "XXXXXXXXXXXX"

SMTPSession smtp;                                   // Объект SMTP

#define ON_Board_LED 2                              //  GPIO2(D4). Светодиод на плате

void setup() {  
  Serial.begin(115200);
  Serial.println();
  pinMode(ON_Board_LED,OUTPUT);                     // Светодиод на плате определяем как выход
  digitalWrite(ON_Board_LED, HIGH);                 // Выключаем светодиод

// Подключение esp8266 к Wi-Fi-маршрутизатору или точке доступа
  Serial.print("Connecting to AP");

  WiFi.begin(WIFI_SSID, WIFI_PASSWORD);
  while (WiFi.status() != WL_CONNECTED)
  {
    Serial.print(".");
// Светодиод мигает при подключении к Wi-Fi-маршрутизатору
    digitalWrite(ON_Board_LED, LOW);
    delay(250);
    digitalWrite(ON_Board_LED, HIGH);
    delay(250);
  }

  digitalWrite(ON_Board_LED, HIGH);                   // Выключаем светодиод

  Serial.println("");
  Serial.println("WiFi соединение.");
  Serial.println("IP адрес: ");
  Serial.println(WiFi.localIP());
  Serial.println();
  
   smtp.debug(1);                                     // Отладочная информация 0 - выкл      1 - вкл

   smtp.callback(smtpCallback);                       // ФункциЯ обратного вызова для получения результатов отправки
 
  ESP_Mail_Session session;

 // Конфигурация сеанса
  session.server.host_name = SMTP_HOST;
  session.server.port = SMTP_PORT;
  session.login.email = AUTHOR_EMAIL;
  session.login.password = AUTHOR_PASSWORD;

  SMTP_Message message;                               // Класс сообщения

 // Устанавливаем заголовок сообщения
  message.sender.name = "DHT11-ESP";                              // ЗАГОЛОВОК 
  message.sender.email = AUTHOR_EMAIL;
  message.subject = "Тревога. Превышена температура";             // Тело письма
  message.addRecipient("DHT11-ESP", "XXXXXXXXXXXX@gmail.com");    // Заголовок и адрес получателя можно указать любую почту на других серверах

  // Сообщение письма
  String textMsg;
  textMsg = "Температура превышена\n Это сообщение отправлено с ОХРАНЯЕМОГО ОБЪЕКТА, помощью ESP8266";
   message.text.content = textMsg.c_str();

  // Кодировка текста
  /** 
   * us-ascii
   * utf-8
   * utf-7
   * По умолчанию utf-8
  */
  message.text.charSet = "utf-8";
 
  // Кодировка передачи сообщения
  /**
   * The content transfer encoding e.g.
   * enc_7bit or "7bit" (not encoded)
   * enc_qp or "quoted-printable" (encoded)
   * enc_base64 or "base64" (encoded)
   * enc_binary or "binary" (not encoded)
   * enc_8bit or "8bit" (not encoded)
   * The default value is "7bit"
  */
  message.text.transfer_encoding = Content_Transfer_Encoding::enc_7bit;

  // Приоритет сообщения
  /**
   * The message priority
   * esp_mail_smtp_priority_high or 1
   * esp_mail_smtp_priority_normal or 3
   * esp_mail_smtp_priority_low or 5
   * The default value is esp_mail_smtp_priority_low
  */
  message.priority = esp_mail_smtp_priority::esp_mail_smtp_priority_high;
 
  // Уведомления О Статусе Доставки
  /** 
   * The Delivery Status Notifications e.g.
   * esp_mail_smtp_notify_never
   * esp_mail_smtp_notify_success
   * esp_mail_smtp_notify_failure
   * esp_mail_smtp_notify_delay
   * The default value is esp_mail_smtp_notify_never
  */
  message.response.notify = esp_mail_smtp_notify_success | esp_mail_smtp_notify_failure | esp_mail_smtp_notify_delay;
 
// Установите пользовательский заголовок сообщения
  message.addHeader("Message-ID: <test.send@gmail.com>");
  
   if (!smtp.connect(&session)) return;                    // Подключение к серверу с конфигурацией сеанса

// Отправка электронной почты и закрытие сеанса
  if (!MailClient.sendMail(&smtp, &message)) Serial.println("Error sending Email, " + smtp.errorReason());
}

void loop() {
   
}

// Функция обратного вызова для получения статуса отправки электронной почты
void smtpCallback(SMTP_Status status) {
  Serial.println(status.info());                          // Печать статуса

// Печать результата отправки сообщения
  if (status.success()) {
    Serial.println("----------------");
    Serial.printf("Сообщение отправлено успешно: %d\n", status.completedCount());
    Serial.printf("Сообщение отправить не удалось: %d\n", status.failedCount());
    Serial.println("----------------\n");
    struct tm dt;
    
    for (size_t i = 0; i < smtp.sendingResult.size(); i++) {
      SMTP_Result result = smtp.sendingResult.getItem(i);
      Serial.printf("Сообщение №: %d\n", i + 1);
      Serial.printf("Статус: %s\n", result.completed ? "Успешно" : "Ошибка");
      Serial.printf("Дата/Время: %d/%d/%d %d:%d:%d\n", dt.tm_year + 1900, dt.tm_mon + 1, dt.tm_mday, dt.tm_hour, dt.tm_min, dt.tm_sec);
      Serial.printf("Получатель: %s\n", result.recipients);
      Serial.printf("Тема: %s\n", result.subject);
    }
    Serial.println("----------------\n");
  }
}
